aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/fileio.c
diff options
context:
space:
mode:
authorJustin M. Keyes <justinkz@gmail.com>2014-09-26 16:05:49 -0400
committerJustin M. Keyes <justinkz@gmail.com>2014-09-26 16:05:49 -0400
commitd97a8e312e506b710284ca3495ed1eb4ea172f73 (patch)
treeddf67487c4076ddc79d6f7c3cd6e7f5f22ea83b1 /src/nvim/fileio.c
parentf7bb349848de3be4013e30e8a5f603aa7db5a4a8 (diff)
parent2b937fe00d8b0b308cce87aee9f70699f8474c1e (diff)
downloadrneovim-d97a8e312e506b710284ca3495ed1eb4ea172f73.tar.gz
rneovim-d97a8e312e506b710284ca3495ed1eb4ea172f73.tar.bz2
rneovim-d97a8e312e506b710284ca3495ed1eb4ea172f73.zip
Merge pull request #1209 from atwupack/vp-7.4.320
vim-patch:7.4.320
Diffstat (limited to 'src/nvim/fileio.c')
-rw-r--r--src/nvim/fileio.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/src/nvim/fileio.c b/src/nvim/fileio.c
index ec91949def..fbce4428db 100644
--- a/src/nvim/fileio.c
+++ b/src/nvim/fileio.c
@@ -6750,7 +6750,8 @@ apply_autocmds_group (
--nesting; /* see matching increment above */
// When stopping to execute autocommands, restore the search patterns and
// the redo buffer. Free buffers in the au_pending_free_buf list.
if (!autocmd_busy) {
restore_search_patterns();
restoreRedobuff();
@@ -6760,6 +6761,11 @@ apply_autocmds_group (
free(au_pending_free_buf);
au_pending_free_buf = b;
}
+ while (au_pending_free_win != NULL) {
+ win_T *w = au_pending_free_win->w_next;
+ free(au_pending_free_win);
+ au_pending_free_win = w;
+ }
}
/*
@@ -6750,7 +6750,8 @@ apply_autocmds_group (
// When stopping to execute autocommands, restore the search patterns and
- // the redo buffer. Free buffers in the au_pending_free_buf list.
+ // the redo buffer. Free any buffers in the au_pending_free_buf list and
+ // free any windows in the au_pending_free_win list.
if (!autocmd_busy) {
restore_search_patterns();